@@ -176,18 +176,6 @@ describe 'tempest' do
 
           is_expected.to contain_class('tempest::params')
 
-          if platform_params[:pip_package_name]
-            is_expected.to contain_package('pip').with(
-              :name => platform_params[:pip_package_name],
-            )
-          end
-
-          is_expected.to contain_exec('install-tox').with(
-            :command => [platform_params[:pip_command], 'install', '-U', 'tox'],
-            :unless  => 'which tox',
-            :path    => ['/bin', '/usr/bin', '/usr/local/bin'],
-          )
-
           is_expected.to contain_vcsrepo('/var/lib/tempest').with(
             :ensure   => 'present',
             :source   => 'https://opendev.org/openstack/tempest',
@@ -207,8 +195,8 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('auth/admin_user_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/default_credentials_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/admin_password').with_secret( true )
-          is_expected.to contain_tempest_config('auth/admin_project_name').with(:value => nil)
-          is_expected.to contain_tempest_config('auth/admin_username').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/admin_project_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('auth/admin_username').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/admin_system').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/tempest_roles').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => '<SERVICE DEFAULT>')
@@ -217,6 +205,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('compute/flavor_ref_alt').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref_alt').with(:value => nil)
+          is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
           is_expected.to contain_tempest_config('compute/build_interval').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('compute/build_timeout').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('image/build_interval').with(:value => '<SERVICE DEFAULT>')
@@ -226,24 +215,24 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('volume/build_interval').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('volume/build_timeout').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('object-storage/build_timeout').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => false)
+          is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('compute-feature-enabled/resize').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
-          is_expected.to contain_tempest_config('validation/image_alt_ssh_user').with(:value => nil)
-          is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
+          is_expected.to contain_tempest_config('compute-feature-enabled/vnc_console').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('validation/image_alt_ssh_user').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('validation/run_validation').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('validation/ssh_key_type').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/auth_version').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('identity/alt_password').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/alt_password').with_secret( true )
-          is_expected.to contain_tempest_config('identity/alt_project_name').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/alt_username').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/alt_password').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/alt_password').with(:value => '<SERVICE DEFAULT>').with_secret( true )
+          is_expected.to contain_tempest_config('identity/alt_project_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/alt_username').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/alt_project_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/alt_user_domain_name').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('identity/password').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/password').with_secret( true )
-          is_expected.to contain_tempest_config('identity/project_name').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/username').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/password').with(:value => '<SERVICE DEFAULT>').with_secret(true)
+          is_expected.to contain_tempest_config('identity/project_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/username').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/project_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/user_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/uri').with(:value => '<SERVICE DEFAULT>')
@@ -254,8 +243,8 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('l2gw/l2gw_switch').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
-          is_expected.to contain_tempest_config('network/public_router_id').with(:value => nil)
+          is_expected.to contain_tempest_config('network/floating_network_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('network/public_router_id').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('dashboard/dashboard_url').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('dashboard/disable_ssl_certificate_validation').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('database/db_flavor_ref').with(:value => nil)
@@ -282,6 +271,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/octavia').with(:value => false)
           is_expected.to contain_tempest_config('service_available/barbican').with(:value => false)
           is_expected.to contain_tempest_config('service_available/manila').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/cloudkitty').with(:value => false)
           is_expected.to contain_tempest_config('enforce_scope/barbican').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/cinder').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/glance').with(:value => '<SERVICE DEFAULT>')
@@ -307,23 +297,37 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('baremetal/max_microversion').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('share/min_api_microversion').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('share/max_api_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('compute/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('image/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('network/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('object_store/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('placement/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('volume/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('heat_plugin/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('alarming/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('metric/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('baremetal/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('dns/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/catalog_type').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/catalog_type').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('dns/nameservers').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('heat_plugin/auth_url').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('heat_plugin/auth_version').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('heat_plugin/admin_password').with_secret( true )
-          is_expected.to contain_tempest_config('heat_plugin/admin_project_name').with(:value => nil)
-          is_expected.to contain_tempest_config('heat_plugin/admin_username').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/admin_password').with(:value => '<SERVICE DEFAULT>').with_secret( true )
+          is_expected.to contain_tempest_config('heat_plugin/admin_project_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('heat_plugin/admin_username').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('heat_plugin/admin_project_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('heat_plugin/admin_user_domain_name').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('heat_plugin/password').with(:value => nil)
-          is_expected.to contain_tempest_config('heat_plugin/password').with_secret( true )
-          is_expected.to contain_tempest_config('heat_plugin/project_name').with(:value => nil)
-          is_expected.to contain_tempest_config('heat_plugin/username').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/password').with(:value => '<SERVICE DEFAULT>').with_secret(true)
+          is_expected.to contain_tempest_config('heat_plugin/project_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('heat_plugin/username').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('heat_plugin/image_ref').with(:value => nil)
           is_expected.to contain_tempest_config('heat_plugin/instance_type').with(:value => nil)
           is_expected.to contain_tempest_config('heat_plugin/minimal_image_ref').with(:value => nil)
           is_expected.to contain_tempest_config('heat_plugin/minimal_instance_type').with(:value => nil)
           is_expected.to contain_tempest_config('baremetal/driver').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('baremetal/enabled_drivers').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('load_balancer/member_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('load_balancer/admin_role').with(:value => '<SERVICE DEFAULT>')
@@ -341,7 +345,6 @@ describe 'tempest' do
           )
           is_expected.to contain_tempest_config('scenario/img_file').with(:value => '/var/lib/tempest/cirros-0.4.0-x86_64-disk.img')
           is_expected.to contain_tempest_config('scenario/img_disk_format').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_oslo__log('tempest_config').with(
             :debug                         => '<SERVICE DEFAULT>',
             :log_file                      => '<SERVICE DEFAULT>',
@@ -349,8 +352,6 @@ describe 'tempest' do
             :use_syslog                    => '<SERVICE DEFAULT>',
             :logging_context_format_string => '<SERVICE DEFAULT>'
           )
-
-          is_expected.not_to contain_tempest_config('magnum/keypair_id').with_value('default')
         end
 
         it 'set glance id' do
@@ -386,7 +387,7 @@ describe 'tempest' do
 
         it 'sets up virtualenv for tempest' do
           is_expected.to contain_exec('create-venv').with(
-            :command => ['virtualenv', '-p', 'python3', '/var/lib/tempest/.venv'],
+            :command => ['python3', '-m', 'venv', '/var/lib/tempest/.venv'],
             :creates => '/var/lib/tempest/.venv',
             :path    => ['/bin', '/usr/bin', '/usr/local/bin']
           )
@@ -395,7 +396,7 @@ describe 'tempest' do
         it 'installs tempest into the virtualenv' do
           is_expected.to contain_exec('install-tempest').with(
             :command     => [
-              'virtualenv', '-p', 'python3', '/var/lib/tempest/.venv'
+              'pytho3', '-m' 'venv', '/var/lib/tempest/.venv'
             ],
             :command     => [
               "/var/lib/tempest/.venv/bin/#{platform_params[:pip_command]}", 'install',
@@ -568,12 +569,9 @@ describe 'tempest' do
                                        'libxml2-dev',
                                        'libssl-dev',
                                        'libffi-dev',
-                                       'patch',
-                                       'gcc',
-                                       'python3-virtualenv'],
+                                       'gcc'],
             :package_name          => 'tempest',
             :pip_command           => 'pip3',
-            :pip_package_name      => 'python3-pip',
             :python_heat_tests     => 'heat-tempest-plugin',
             :python_keystone_tests => 'keystone-tempest-plugin',
             :python_neutron_tests  => 'neutron-tempest-plugin',
@@ -584,11 +582,9 @@ describe 'tempest' do
                                        'libxml2-devel',
                                        'openssl-devel',
                                        'libffi-devel',
-                                       'patch',
                                        'gcc'],
             :package_name          => 'openstack-tempest',
             :pip_command           => 'pip3',
-            :pip_package_name      => 'python3-pip',
             :python_heat_tests     => 'python3-heat-tests-tempest',
             :python_keystone_tests => 'python3-keystone-tests-tempest',
             :python_neutron_tests  => 'python3-neutron-tests-tempest',
